---
title: Markata's Docs
codeUrl: https://github.com/WaylonWalker/markata/
url: https://markata.dev/

---

[![Markta.dev home page](/markata.dev_.webp)](https://markata.dev)

Markata builds it's own docs in completely in `markata` using all built in
templatates and plugins.


[![Markta.dev home page](/markata.dev_markata_plugins_base-cli_.webp)](https://https://markata.dev/markata/plugins/base-cli/)

Using the `markata.plugins.docs` plugin it is able to load all the python
files.  It renders out all the docstrings as markdown and shows the code in
highlighted code blocks.
